@@ -1,5 +1,5 @@
 package Proc::tored::Machine;
-$Proc::tored::Machine::VERSION = '0.14';
+$Proc::tored::Machine::VERSION = '0.15';
 use strict;
 use warnings;
 use Moo;
@@ -61,7 +61,7 @@ my $FSM = machine {
   transition LOCK,   to STATUS, on $Locked,   using { my $me = $_; $SIG{$_} = sub { $me->{quit} = 1 } foreach @{$me->{traps}}; $_->{started} = 1; $_ };
   transition LOCK,   to TERM,   on $Unlocked;
   # Term
-  transition STOP,   to TERM,   on $Proctor,  using { undef $SIG{$_} foreach @{$_->{traps}}; $_ };
+  transition STOP,   to TERM,   on $Proctor,  using { undef $_->{lock}; undef $SIG{$_} foreach @{$_->{traps}}; $_ };
 };
 
 has pidfile_path => (is => 'ro', isa => NonEmptyStr, required => 1);
@@ -128,7 +128,7 @@ sub run {
 
   $service->($acc);
 
-  return $acc->{lock};
+  return $acc->{started};
 };
 
 1;
@@ -145,7 +145,7 @@ Proc::tored::Machine
 
 =head1 VERSION
 
-version 0.14
+version 0.15
 
 =head1 AUTHOR
 
