@@ -1,6 +1,6 @@
 package Proc::tored::PidFile;
 # ABSTRACT: Manage a service using a pid file
-$Proc::tored::PidFile::VERSION = '0.14';
+$Proc::tored::PidFile::VERSION = '0.15';
 
 use warnings;
 use strict;
@@ -21,6 +21,8 @@ sub _build_file { path(shift->file_path) }
 has write_lock_file => (is => 'lazy', isa => InstanceOf['Path::Tiny']);
 sub _build_write_lock_file { path(shift->file_path . '.lock') }
 
+has mypid => (is => 'ro', isa => Int, default => sub { $$ }, init_arg => undef);
+
 
 sub is_running {
   my $self = shift;
@@ -77,6 +79,7 @@ sub lock {
 #-------------------------------------------------------------------------------
 sub write_lock {
   my $self = shift;
+  return unless $$ eq $self->mypid;
 
   # Existing .lock file means another process came in ahead
   my $lock = $self->write_lock_file;
@@ -116,7 +119,7 @@ Proc::tored::PidFile - Manage a service using a pid file
 
 =head1 VERSION
 
-version 0.14
+version 0.15
 
 =head1 SYNOPSIS
 
